Renamed injectStatics() to requestStaticInjection().

git-svn-id: https://google-guice.googlecode.com/svn/trunk@38 d779f126-a31b-0410-b53b-1d3aecad763e
diff --git a/src/com/google/inject/ContainerBuilder.java b/src/com/google/inject/ContainerBuilder.java
index 68cf70c..46acc28 100644
--- a/src/com/google/inject/ContainerBuilder.java
+++ b/src/com/google/inject/ContainerBuilder.java
@@ -219,12 +219,12 @@
   }
 
   /**
-   * Upon creation, the {@link Container} will inject static fields and methods
-   * in the given classes.
+   * Upon successful creation, the {@link Container} will inject static fields
+   * and methods in the given classes.
    *
    * @param types for which static members will be injected
    */
-  public void injectStatics(Class<?>... types) {
+  public void requestStaticInjection(Class<?>... types) {
     staticInjections.addAll(Arrays.asList(types));
   }
 
@@ -244,7 +244,7 @@
 
   /**
    * Creates a {@link Container} instance. Injects static members for classes
    * which were registered using {@link #injectStatics(Class...)}.
    *
    * @param loadSingletons If true, the container will load all singletons
    *  now. If false, the container will lazily load singletons. Eager loading
@@ -244,7 +244,7 @@
   /**
    * Creates a {@link Container} instance. Injects static members for classes
-   * which were registered using {@link #injectStatics(Class...)}.
+   * which were registered using {@link #requestStaticInjection(Class...)}.
    *
    * @param loadSingletons If true, the container will load all singletons